with import <nixpkgs> {};

stdenv.mkDerivation rec {
  version = "master";
  name = "r6d-base-${version}";

  buildInputs = [
    # Adminsys
    cowsay        # pour ansible & 4lulz
    iotop
    lm_sensors
    lshw
    lsof
    ntp
    powerline-fonts
    powertop
    python27Packages.ansible2
    python27Packages.glances
    usbutils

    # Backup
    duplicity     # création de sauvegarde chiffrées (GPG)

    # Compression
    lz4
    lzop

    # Système de fichier
    ## Montage de filesystem
    curlftpfs     # ftp
    exfat         # Pour monter les FAT avec Fuse
    hubicfuse     # montage hubic
    ntfs3g        # ntfs
    samba         # partages windows
    squashfsTools # squashfs
    sshfsFuse     # ssh

    ## Gestion de FS
    nfs-utils

    ## Exploitation FS
    inotify-tools # être notifié lorsque le contenu d'un répertoire change
    detox			# The detox utility renames files to make them easier to work with.
    duff          # outil de recherche de fichiers en doublons
    rdfind        # recherche de fichiers doublons pour remplacement par hard/soft link

      ## Gestion de FS
      gparted       # Gestion graphique de partitions
      unetbootin    # création de clefs USB bootables

   # Environement de bureau
    arandr          # interface graphique pour xrandr
    wmname          # pour définir le nom du gestionnaire de fenêtre (utile pour java)
    #kde4.ksnapshot # capture d'écran
    xclip           # manipulation du clipboard X depuis la console
    xorg.xbacklight # pour gérer la luminosité de l'écran
    xorg.xev        # pour repérer les codes + noms standard des actions clavier/souris
    xorg.xkill      # pour 'tuer une application'

    ## Gestionnaire de fenêtre & Thème
    gnome3.adwaita-icon-theme  # thème d'icone - semble fonctionner avec spaceFM

    ## Manipulation de fichier
    pcmanfm         # gestionnaire de fichiers graphique
    spaceFM         # gestionnaire de fichiers graphique
    #vifm            # gestionnaire de fichiers basé sur VIM (console)

    ## Terminal
    sakura          # terminal


      # Bureautique
    aspell aspellDicts.fr # correction d'ortographe
    gnumeric      # tableur
    #kde4.ksnapshot# réalisation de capture d'écran

    # Gestion de tâche
    taskwarrior     # gestionnaire de tâches en console

    ## Cartes mentales
    freemind

    ## Diagrammes & Schémas
    dia           # dessin & schéma technique

    ## Editeur de texte
    #lyx          # surcouche WISIWIM à LaTeX
    #focuswriter  # outil pour l'écriture
    textadept     # un éditeur de texte facile pour copier-coller graphique
    #zim          # outil de prise de notes, wiki de bureau

    ## Visionneuse
    #kde5.okular   # pdf
    mcomix        # livres (cbr, liste d'images), gestion d'une bibliothèque
    pdfpc         # pdf
    qpdfview      # pdf
    gqview        # visionneuse image & gestion basique de collection

    ## Convertisseurs (texte -> <autre format>)
    gnuplot       # générateur de graphes à partir de données numériques
    graphviz      # dot, neato : traçage de graphes (carré, rond)
    #jekyll       # générateur statique de site web
    #odpdown      # conversion md -> presentation ODP : https://github.com/thorstenb/odpdown
    pandoc
    haskellPackages.pandoc-citeproc
    texlive.combined.scheme-full # distribution LaTeX
    #texLive       # distribution LaTeX de base
    #texLiveBeamer # paquets et extensions pour Beamer
    #texLiveModerncv # paquets pour la classe Modern CV


    # CAO
    ## Modélisation 3D
    freecad   # modélisation de pièces en 3D
    povray    # Rendu tracé de rayon, utilisé dans freecad

    ## Électricité & Électronique
    fritzing  # schéma de câblages "jolis"
    kicad     # ensemble d'outils de conception électronique
    qucs      # simulateur de circuits électroniques

        expat
    gpsbabel      # pour convettir les données des GPS
    josm          # outil de contribution à OpenStreetMap
    #qgis         # client lourd de manipulation de données géographiques
    viking        # analyse de topo, gestion de données GPS

  ];

  meta = with stdenv.lib; {
    description = "Meta programs that depends on all required programs";
    license = licenses.cc-by-nc-sa-40;
    maintainers = [ "Jean-Pierre PRUNARET <jean-pierre+git@prunetwork.fr>" ];
    platforms = platforms.linux;
  };
}
